<?php
/**
 * Essence Pro.
 *
 * Onboarding config to load plugins and homepage content on theme activation.
 *
 * @package Essence Pro
 * @author  StudioPress
 * @license GPL-2.0-or-later
 * @link    https://my.studiopress.com/themes/essence/
 */

$essence_onboarding_config = [
	'dependencies'     => [
		'plugins' => [
			[
				'name'       => __( 'Atomic Blocks', 'essence-pro' ),
				'slug'       => 'atomic-blocks/atomicblocks.php',
				'public_url' => 'https://atomicblocks.com/',
			],
			[
				'name'       => __( 'WPForms Lite (Third Party)', 'essence-pro' ),
				'slug'       => 'wpforms-lite/wpforms.php',
				'public_url' => 'https://wordpress.org/plugins/wpforms-lite/',
			],
		],
	],
	'content'          => [
		'homepage' => [
			'post_title'     => 'Live The Life You Deserve',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/homepage.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'page_template'  => 'page-templates/blocks.php',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
		],
		'blocks'   => [
			'post_title'     => 'Block Content Examples',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/block-examples.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
			'meta_input'     => [ '_genesis_layout' => 'full-width-content' ],
		],
		'about'    => [
			'post_title'     => 'About Us',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/about.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'featured_image' => CHILD_URL . '/config/import/images/about.jpg',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
			'meta_input'     => [ '_genesis_layout' => 'full-width-content' ],
		],
		'contact'  => [
			'post_title'     => 'Contact Us',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/contact.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
		],
		'landing'  => [
			'post_title'     => 'Landing Page',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/landing-page.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'page_template'  => 'page-templates/landing.php',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
			'meta_input'     => [
				'_genesis_layout'              => 'full-width-content',
				'_genesis_hide_breadcrumbs'    => true,
				'_genesis_hide_singular_image' => true,
			],
		],
		'pricing'  => [
			'post_title'     => 'Pricing Page',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/pricing-page.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
			'meta_input'     => [ '_genesis_layout' => 'full-width-content' ],
		],
	],
	'navigation_menus' => [
		'primary' => [
			'homepage' => [
				'title' => 'Home',
			],
			'about'    => [
				'title' => 'About Us',
			],
			'contact'  => [
				'title' => 'Contact Us',
			],
			'blocks'   => [
				'title' => 'Block Examples',
			],
			'landing'  => [
				'title' => 'Landing Page',
			],
			'pricing'  => [
				'title' => 'Pricing Page',
			],
		],
	],
];

// Import sample posts if the site is fresh.
if ( get_option( 'fresh_site' ) ) {
	$essence_onboarding_config['content']['sample-post-1'] = [
		'post_title'     => 'Why Space and Tranquillity Matter in Your Minimal Lifestyle',
		'post_content'   => require dirname( __FILE__ ) . '/import/content/post-example.php',
		'post_type'      => 'post',
		'post_status'    => 'publish',
		'featured_image' => CHILD_URL . '/config/import/images/sample-post-1.jpg',
		'comment_status' => 'closed',
		'ping_status'    => 'closed',
	];
	$essence_onboarding_config['content']['sample-post-2'] = [
		'post_title'     => 'The Secret Method to Creating the Perfect Amount of Simple',
		'post_content'   => require dirname( __FILE__ ) . '/import/content/post-example.php',
		'post_type'      => 'post',
		'post_status'    => 'publish',
		'featured_image' => CHILD_URL . '/config/import/images/sample-post-2.jpg',
		'comment_status' => 'closed',
		'ping_status'    => 'closed',
	];
	$essence_onboarding_config['content']['sample-post-3'] = [
		'post_title'     => 'Understanding the Benefits of Good Nutrition',
		'post_content'   => require dirname( __FILE__ ) . '/import/content/post-example.php',
		'post_type'      => 'post',
		'post_status'    => 'publish',
		'featured_image' => CHILD_URL . '/config/import/images/sample-post-3.jpg',
		'comment_status' => 'closed',
		'ping_status'    => 'closed',
	];
	$essence_onboarding_config['content']['sample-post-4'] = [
		'post_title'     => 'Unplug and Connect with Your Soul',
		'post_content'   => require dirname( __FILE__ ) . '/import/content/post-example.php',
		'post_type'      => 'post',
		'post_status'    => 'publish',
		'featured_image' => CHILD_URL . '/config/import/images/sample-post-4.jpg',
		'comment_status' => 'closed',
		'ping_status'    => 'closed',
	];
	$essence_onboarding_config['content']['sample-post-5'] = [
		'post_title'     => 'Increase Your Productivity as a Working Parent',
		'post_content'   => require dirname( __FILE__ ) . '/import/content/post-example.php',
		'post_type'      => 'post',
		'post_status'    => 'publish',
		'featured_image' => CHILD_URL . '/config/import/images/sample-post-5.jpg',
		'comment_status' => 'closed',
		'ping_status'    => 'closed',
	];
}

return $essence_onboarding_config;
